#
# spec file for package ibus-table
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-table
Version:        1.17.8
Release:        1.3
Summary:        The Table engine for IBus platform
License:        LGPL-2.1-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/mike-fabian/ibus-table/
Source:         https://github.com/mike-fabian/ibus-table/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  docbook-utils-minimal
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  gnome-common
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(python3)
Requires:       ibus >= 1.4.99
Requires:       python3
Requires:       python3-curses
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The package contains general Table engine for IBus platform.

%package devel
Summary:        Development package for ibus-table
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
This package contains the files required for the development of ibus-table.

%prep
%setup -q
chmod -x AUTHORS COPYING README

%build
export PYTHON=python3
NOCONFIGURE=1 ./autogen.sh
%configure --disable-static \
           --enable-additional \
           --libexecdir=%{_ibus_libexecdir}
%make_build

%install
%make_install NO_INDEX=true

%find_lang %{name}
%fdupes %{buildroot}

%files -f %{name}.lang
%license COPYING
%doc AUTHORS README NEWS ChangeLog
%{_bindir}/%{name}-createdb
%{_ibus_libexecdir}/ibus-engine-table
%{_ibus_libexecdir}/ibus-setup-table
%{_datadir}/applications/ibus-setup-table.desktop
%{_datadir}/%{name}
%{_datadir}/glib-2.0/schemas/org.freedesktop.ibus.engine.table.gschema.xml
%{_ibus_componentdir}/table.xml
%{_mandir}/man1/%{name}-createdb.1.gz
%{_datadir}/metainfo/ibus-table.appdata.xml
%{_datadir}/icons/hicolor/16x16/apps/ibus-table.png
%{_datadir}/icons/hicolor/22x22/apps/ibus-table.png
%{_datadir}/icons/hicolor/32x32/apps/ibus-table.png
%{_datadir}/icons/hicolor/48x48/apps/ibus-table.png
%{_datadir}/icons/hicolor/64x64/apps/ibus-table.png
%{_datadir}/icons/hicolor/128x128/apps/ibus-table.png
%{_datadir}/icons/hicolor/256x256/apps/ibus-table.png
%{_datadir}/icons/hicolor/scalable/apps/ibus-table.svg

%files devel
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Sep 12 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.17.8
  * Update Unihan_Variants.txt and regenerate engine/chinese_variants.py
  for Unicode 16.0.0 release
  * Update translations for Greek
* Sun Aug 25 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.17.7
  * French and Russian weblate translations
* Fri Jun 28 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.17.6
  * Drop Python2 support (using pyupgrade --py3-plus *.py)
  * Make it possible to use keys with Unicode keysyms in keybindings
  * Use frames_per_buffer=chunk_size option in self._paudio.open()
  * Translation update from Weblate (cs 36.6%%, ja 45.3%%, zh_CN 92.0%%)
* Fri Jan 19 2024 Callum Farmer <gmbr3@opensuse.org>
- Fixes for %%_ibus_libexecdir moving to %%_libexecdir (bsc#1174075)
* Fri Nov 10 2023 Gordon Leung <pirateclip@protonmail.com>
- Update version to 1.17.4
  * Fix compose support for ibus >= 1.5.28 (Resolves: #145)
  * Translation update from Weblate (New language, Russian, (ru) 80%%)
* Fri Jul 14 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.17.1
  * Fix mypy warnings
  * Return empty program_name and window_title in get_active_window_xprop() when
    xprop results are unexpected (Resolves:
    https://bugzilla.redhat.com/show_bug.cgi?id=2215466)
  * Translation update from Weblate
* Fri Apr  7 2023 Gordon Leung <pirateclip@protonmail.com>
  update: 1.16.14 -> 1.17.0
- New option commit_invalid_mode: Choose what happens when a character not in
  valid input characters is typed
- More translations
* Fri Nov 11 2022 Gordon Leung <pirateclip@protonmail.com>
  update: 1.16.13 -> 1.16.14
- Fix a problem in C/POSIX and invalid locales: Use lower() on LC_MESSAGES only
  if it is a string and not None
* Thu Nov  3 2022 Gordon Leung <pirateclip@protonmail.com>
  update: 1.16.12 -> 1.16.13
- Get program name of focused window also when ibus cannot get it
- Use focus id if available (it is available for ibus >= 1.5.27)
- Use IBus.PreeditFocusMode.COMMIT and make sure the input is cleared and the UI
  updated when the focus changes
- Do not reset input purpose on focus out
- Do not commit by index when OSK is visible
* Fri Sep  9 2022 Gordon Leung <pirateclip@protonmail.com> - 1.16.12
  update: 1.16.11 -> 1.16.12
- Stop using locale.getdefaultlocale() because it is deprecated in Python 3.11
  and will be removed in Python 3.13
- Add 128x128, 256x256, and svg (remote) icons to ibus-table.appdata.xml
* Sat Aug  6 2022 Gordon Leung <pirateclip@protonmail.com> - 1.16.11
  update: 1.16.10 -> 1.16.11
- Remove hashbang from chinese_variants.py and tabcreatedb.py
  * gh#mike-fabian/ibus-table#118
* Fri Aug  5 2022 Gordon Leung <pirateclip@protonmail.com>
  update: 1.16.9 -> 1.6.10
- Add png versions of the ibus-table.svg icon
- Add (remote) icon to ibus-table.appdata.xml
- Add screenshot to ibus-table.appdata.xml
* Mon Aug  1 2022 Gordon Leung <pirateclip@protonmail.com>
  feat: use _service files to automate fetching sources
* Sat Jun 25 2022 Gordon Leung <pirateclip@protonmail.com> - 1.16.9
  update: 1.13.3 -> 1.16.9
- Now requires Python >= 3.6 to build
- Update Unihan_Variants.txt to "2022-04-26 Unicode 15.0.0 draft"
- Update weblate translations
- Add option to set dynamic adjust at runtime gh#mike-fabian/ibus-table#70
- Add button to forget all data learned by typing and selecting candidates
  * gh#kaio/ibus-table#75
- Fix problems with goucima for erbi-qs table gh#kaio/ibus-table#77
- Fix gh#mike-fabian/ibus-table#85
- 栗 U+6817 is used in Traditional Chinese as well gh#mike-fabian/ibus-table#95
- Ignore MOD3_MASK (Scroll Lock) when matching key bindings gh#mike-fabian/ibus-table#102
- When a Modifier key release matches a hotkey command, return False not True
  * gh#mike-fabian/ibus-table#102
* Thu Jun 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.13.3
  * Fix bug in Unihan_Variants.txt, 只 U+53EA is both simplified and traditional
    Chinese (Resolves: #74)
  * Update Chinese variant detection by Unihan_Variants.txt to the version
    “2021-05-18 Unicode 14.0.0” (draft version of Unicode 14)
  * Update translations from Weblate (updates for es (100%%), pt_BR (100%%))
  * Fix a few more bugs in Unihan_Variants.txt, the characters 着枱云裡復采吓尸揾 are
    used both in simplified and traditional Chinese (some of them in traditional
    Chinese in Hong Kong only). (Resolves: ibus/ibus#2323)
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.13.1
  * Fix reading the source file for the suggestions phrase.txt.bz2
  * Update translations from Weblate (updates for ca, fr)
* Sat May  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.13.0
  * Make switch to pinyin mode also happen immediately even when
    the preedit is not empty
  * Make rolling the mouse wheel in the candidate area of the lookup
    table work
  * Commit English input and then switch into direct mode
  * Apply a couple modes immediately when changed
  * Show all the tabkeys when using wildcards
  * In main.py “import factory” only when the --xml option
    is not used
  * Make the keybindings treeview sortable by clicking the column
    headers
  * Return False in _execute_command_commit_candidate_number(self, number)
    if number out of range
  * Add a dark theme option
  * Remove Python2 compatibility
  * Update translations, update for:
    cs, de, es, fa, ja, tr, uk, zh_CN , pt_BR, zh_CN
  * zh_CN and pt_BR are 100%% complete now
  * Sinhala (si) started
* Mon Jan 11 2021 Dingzhong Chen <wsxy162@gmail.com>
- Drop ibus-table_fix_other_tables_compile_error.patch, fixed in the
  upstream version 1.9.23
- Update version to 1.12.3
  * Pass the key for the command 'cancel' (default Esc) through if the preedit
    is empty (Resolves: #64)
- Update version to 1.12.2
  * Update translations from Weblate (updated ca, cs, es, fa, ja, pt_BR, pt_PT,
    tr, zh_CN, zh_HK, zh_TW)
- Update version to 1.12.1
  * Enable compose support.
  * Add buttons to move key bindings for a command up or down.
  * Make translations of 'Edit key bindings for command “%%s”' work
  * Added it_util.py to POTFILES, it had translatable strings for the “About”
    dialog and the key settings dialog.
  * Update translations from Weblate (updated ca, de, fr, tr, uk)
- Update version to 1.12.0
  * New setup tool, now keybindings can be configured with a GUI.
  * Resolves: #57
  * Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=1133127
  * Put exact (except tone) pinyin matches next after exact
  * matches in the candidate list.
  * Resolves: #63
  * Allow lookup table orientation “System Default” in the setup
  * Remove “spacekeybehavior” option, it became useless as all
  * keybindings are configurable now.
  * Added a “debuglevel” option.
  * Update translations from Weblate (updated ca, cs, de, es, fa, fr, ja, pt_BR,
    pt_PT, uk, zh_TW, zh_HK, zh_CN)
- Update version to 1.11.0
  * Make key bindings configurable (Only via the command line for the moment,
    not yet easy to do for normal users. I have to rewrite the setup tool
    eventually to make that possible)
  * Resolves: ibus/ibus#2241
  * Resolves: mike-fabian#41
- Update version to 1.10.1
  * Add GUI test
  * Make output of ibus-table-createdb deterministic
  * Update translations from Weblate (updated fr, tr, zh_CN)
- Update version to 1.10.0
  * Add suggestion mode feature (Resolves: mike-fabian#9 and rhbz#835376)
  * Add test cases for suggestion mode feature
  * Fix problems with the behaviour of the property menus
  * Use python logging module with log file rotation instead of writing to
    stdout/stderr
  * Update translations from Weblate (updated de, es, fr, pt_BR, pt_PT, tr, uk)
- Update version to 1.9.25
  * Fix crash when changing some options using the menu or the floating
    panel (Resolves: mike-fabian#26)
  * Translation updates (pt_PT)
- Update version to 1.9.24
  * Fixed two typos in message ids (Thanks to Rafael Fontenelle)
  * Translation updates (tr, fr, fa, pt, uk)
  * New test cases for ibus-table-others
- Update version to 1.9.23
  * Add exist_ok=True in os.makedirs(path, exist_ok=True) to avoid
    failure due to race condition.
    Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=1786652
  * Move MockEngine classes into a separate file and make test_itb.py
    runnable standalone
  * Translation updates for several languages (French at 100%% now, Brazilian
    Portuguese at 100%% now, Porguguese (Portugal) new and now at 31.5%%)
- Update version to 1.9.22
  * Add Turkish translation from Weblate, 100%% translated
  * Minor translation fixes in some other languages (Punctuation fixes)
* Wed Feb 19 2020 Cliff Zhao <qzhao@suse.com>
- Add ibus-table_fix_other_tables_compile_error.patch: Fix ibus
  other tables compile errors(bnc#1160315).
* Sat Oct 13 2018 hillwood@opensuse.org
- Update version to 1.9.21
  * Migrate IBusConfig to GSettings.
  * Add a test suite
  * Add missing tags to ibus-table-createdb.sgml.
  * Draw InputMode text instead of icon into panel on non-Gnome desktops.
  * Make it work with Python2 again
  * Sync phrases cache from/to external storage.
  * Update translations from zanata
  * validate ibus-table.appdata.xml in %%%%check
  * Update translations from zanata (pt_BR updated, es new)
  * Don't query user database if user define phrase and dynamic adjust
    are disabled (thanks to heiher)
  * Enable hash map based cache for user database enabled
  * Import hash map based cache for table database (thanks to heiher)
  * Install appstream metadata to /usr/share/metainfo/ (thanks to jbicha)
  * Fix some appdata validation issues (thanks to jbicha)
  * Fix bug in Unihan_Variants.txt, 著 U+8457 is both
    simplified and traditional Chinese (thanks to heiher)
* Fri Dec 15 2017 hillwood@opensuse.org
- Update to 1.9.17. This update will fix boo#939462
  * Load .desktop file for ibus-setup-table correctly under Gnome Wayland
  * Set WM_CLASS of ibus-setup-table correctly
  * Avoid running initialization code of ibus_table_location.py
  * when using ibus-table-createdb.
  * Make it work on Python 3.6 (Unbreak sqlite on Python 3.6)
  * (Resolves: rhbz#1413580).
  * Update translations from zanata (ca, de, fr, uk updated)
  * Point to new home-page in the “About” tab.
  * Improve README
  * Fix bug in Unihan_Variants.txt, 乾 U+4E7E is both simplified and traditional
    Chinese (thanks to Heiher r@hev.cc)
  * When ignoring key release events, “False” should be returned, not “True”
  * Resolves: Resolves: rhbz#1369514
  * add ibus-table.appdata.xml and make it translatable
  * pull some new translations and updates from Zanata (ca, fr, pt_BR, and uk
    are new, ja, zh_CN, and zh_TW have updates).
- Drop ibus-table-python3.patch, It is needless.
* Sun Sep 28 2014 hillwood@linuxfans.org
- update to 1.8.11
  * Fix typo in variable name self_onechar -> self._onechar
  * Disable “onechar” (Phrase mode/Single char mode) option for non-CJK
    databases
  * Disable auto_commit option for tables which do not have RULES
  * Resolves: rhbz#1135759 - The rusle is broken with "Normal commit mode"
    See: https://bugzilla.redhat.com/show_bug.cgi?id=1135759
  * Pass IBus.KEY_KP_Enter to the application if the preedit is empty
  * Resolves: rhbz#1133424 - With the new "rusle" table in ibus-table-cyrillic,
    Keypad Enter problem
    See: https://bugzilla.redhat.com/show_bug.cgi?id=1133424
  * Ignore Shift+Space hotkey to switch fullwidth/halfwidth if the database
    is not for CJK
  * Move some options into a new tab “Details”
  * Disable properties related to fullwidth/halfwidth for non-CJK tables
  * Remove “Hide Candidates/Display Candidates” from the properties menu
  * Show keyboard shortcuts also in the property menu entries
  * Use the “notify::text” signal instead of “activate” on GtkEntry widget
  * Update Chinese .po files
  * Update German translation
  * Move the “Restore all defaults” button into the GtkButtonBox at bottom
  * Apply fix for 同 again to Unihan_Variants.txt, it is both simplified *and*
    traditional Chinese
  * And regenerate engine/chinese_variants.py.
  * Escape %% and _ if they are not intended as wildcards
  * Require Python >= 3.3
* Sat Jul 26 2014 i@marguerite.su
- update version 1.8.5
  * Always write xml output in UTF-8 encoding, not in the encoding
    of the current locale
- changes since 1.8.4
  * Tweak defaults for Chinese mode taken from the locale
  * Fix prompts for array30 table and don’t use prompts in pinyin mode
  * Make it possible to use select keys like F1, F2, F3 ...
  * For cangjie* and quick* tables: Use big5 order if the freq from
    the table is the same
- add ibus-table-python3.patch
  * replace file() to open()
* Sat Jul 26 2014 hillwood@linuxfans.org
- Switch python to python3
* Fri Jul  4 2014 hillwood@linuxfans.org
- Updateto 1.8.3, ibus-table >= 1.8.x has many improvements over 1.5.x
  * The database format is simplified which makes better matching
    possible. But because of the changed database format, the
    tables have to be rebuilt, i.e. packages like ibus-table-chinese
    and ibus-table-others have to be rebuilt against  ibus-table > 1.8.0.
  * Wildcard support added, wildcards like ? for single characters or *
    for many characters can be used. The wildcards can be configured
    in the setup tool, for example one can also use 'z' as a single character
    wildcard if desired.
  * Setup tool improved, several new options added, works with Gnome3 now.
  * Prompt characters are supported now, for example when using Cangjie,
    日, 月, 金, ... are displayed while typing instead of a, b, c, ...
  * Moving around in the preëdit works correctly now. One can commit
    the current candidate to preëdit with the left shift key or with
    the arrow keys, commit more characters to preëdit that way, then
    move around in the preëdit and see the full key sequences of the
    characters in the preëdit. This way one can check the
    key sequences if one used wildcards or pinyin mode to enter the
    characters.
  * Fix many bugs
* Fri Feb 14 2014 fcrozat@suse.com
- Fix missing capital on devel package group.
* Sun Dec 15 2013 swyear@gmail.com
- Add Requires: python-curses, ibus-engine-table need this module,
  but it is not installed in some system, e.g Live KDE
* Mon Jul  8 2013 hillwood@linuxfans.org
- Update to 1.5.0
  * Updated PO files.
  * Make page up/down keys configurable
* Sun Jan 13 2013 hillwood@linuxfans.org
- fix bnc#803488
* Wed Dec 19 2012 hillwood@linuxfans.org
- Update to 1.4.99.20121112
  * Updated PO files
* Fri Oct 12 2012 hillwood@linuxfans.org
- Update to 1.4.99.20121012
  * Updated PO files.
  * Merge remote-tracking branch 'mozbugbox/page-up-down-config' into
* Wed Oct  3 2012 hillwood@linuxfans.org
- update to 1.4.99.20121003, upstream did not provide more information.
* Fri Sep  7 2012 hillwood@linuxfans.org
- update to 1.4.99.20120904
  Package Maintainer: Please test before include this to your distro.
* Wed Jul  4 2012 swyear@gmail.com
- Add ibus as Requires
* Mon Jun 18 2012 hillwood@linuxfans.org
- update to 1.3.9.20110827
- better compatibility for ibus 1.4
* Tue Jun 14 2011 swyear@gmail.com
- Update to 1.3.0;
  major update for ibus-1.3.x infrastructure
- additional had move to package ibus-table-others
* Wed Mar 24 2010 tiwai@suse.de
- fix file list
* Fri Jan 29 2010 mxwu@novell.com
- Initial import.
